@@ -3,10 +3,11 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "0.09";
+our $VERSION = "0.10";
 
-use File::Basename qw/basename/;
 use Carp qw/croak/;
+use DBIx::TransactionManager;
+use File::Basename qw/basename/;
 
 use SQL::Maker;
 SQL::Maker->load_plugin('InsertMulti');
@@ -20,6 +21,13 @@ has dbh => (
     required => 1,
 );
 
+has transaction_manager => (
+    is => 'lazy',
+    default => sub {
+        DBIx::TransactionManager->new(shift->dbh);
+    },
+);
+
 has bulk_insert => (
     is      => 'lazy',
     default => sub {
@@ -177,7 +185,7 @@ sub _load_fixture_from_data {
 
     my $dbh = $self->dbh;
     # needs limit ?
-    $dbh->begin_work or croak $dbh->errstr;
+    my $txn = $self->transaction_manager->txn_scope or croak $dbh->errstr;
 
     my $opt; $opt->{prefix} = 'INSERT IGNORE INTO' if $ignore;
     if ($bulk_insert) {
@@ -199,7 +207,7 @@ sub _load_fixture_from_data {
             $dbh->do( $sql, undef, @binds ) or croak $dbh->errstr;
         }
     }
-    $dbh->commit or croak $dbh->errstr;
+    $txn->commit or croak $dbh->errstr;
 }
 
 sub _build_on_duplicate {
@@ -275,6 +283,12 @@ Using C<< INSERT IGNORE >> or not. This option is exclusive with C<update>.
 Specifying L<Text::CSV>'s option. C<binary> and C<blank_is_undef>
 are automatically set.
 
+=head3 C<< skip_null_column (Bool, Default: false) >>
+
+If true, null data is not to be inserted or updated explicitly. It it for using default value.
+
+NOTE: If this option is true, data can't be overwritten by null value.
+
 =head2 Methods
 
 =head3 C<< $loader->load_fixture($file_or_data:(Str|HashRef|ArrayRef), [%option]) >>
